=======
Credits
=======

Development Lead
----------------

* Dmytro Litvinov <litvinov.do.it@gmail.com> `@Dmytro_Litvinov <https://twitter.com/Dmytro_Litvinov>`_

Contributors
------------

None yet. Why not be the first?
